#ifndef GYRO_SERVER_LIB_H
#define GYRO_SERVER_LIB_H

/**
 ** Copyright (c) 2000-2006 LAAS/CNRS 
 **
 ** Anthony Mallet - Tue Aug  1 2000 
 **
 ** Functions to open, read and decode gyro data on a serial line :
 **
 **      int gyroOpen(char *device)
 **      int gyroRead(int fd, char *buf)
 **      int gyroDecode(GyroData *gyro)
 **
 **/


#define VERBOSE 0

#define GYRO_SERIAL_SPEED		9600

#define GYRO_TEMP_RESOLUTION		(0.05)
#define GYRO_RATE_RESOLUTION		(0.00305 * PI / 180.0)


/* Useless to be more precise than earth revolution = 360/24/3600=0.0042 deg/s.
   Moreover, the gyro KVH1000 precision seems about 0.02 deg/s.
   With the threathold, derivation will be avoid.  */
#define GYRO_W_MIN (0.02*3.1415926/180)

#define GYRO_DEVICE_NAME_LEN	16


/* --
   -- Structure shared by server and client 
   -- */
typedef struct GyroData {
   int fd;		/* serial line */
   char device[GYRO_DEVICE_NAME_LEN];/* serial device */

   int taskId;		/* read task */

   int sn;		/* serial number (SN) */
   int snBit;		/* current SN bit */
   unsigned snI:1;	/* true if first SN bit has been received */
   unsigned snO:1;	/* true if all SN bits have been received */

   float temp;		/* temperature C */
   unsigned char tlsb;	/* lsb */
   unsigned char tmsb;	/* msb */

   float w;		/* angle rate */
   float wOffset;       /* angle rate offset 
			   (to have 0 when there's no motion) */
   double theta;        /* integrated angle */

   u_long date;         /* date of acquisition */
   u_long prevDate;     /* date of previous acquisition */
   u_long resetDate;    /* duration from last angle reset */
   u_long period;       /* duration from previous acquisition */

   int stop;
   int nbMeasuresOffset;

   char buf[8];		/* raw data */
} GyroData;


int gyroOpen(char *device);
int gyroRead(int fd, char *buf, u_long *date);
int gyroDecode(GyroData *gyro);

#define GYRO_EARTH_ROTATION(duration)  ((duration) / 1000.0 * 2.0 * PI / 86400.0)

#endif
